Installation 
============

To install simply run:: 

   pip install triangle
    
or build from source:: 

   git clone https://github.com/drufat/triangle.git 
   cd triangle 
   python setup.py install
